Skip to content

Introduction

Peplum Peplum v1.1.0 — All; Sorted by Date Created (reversed) (747) │All [a]747│851Add list.discard()    Standards Track, Draft│Title ││Stan Ulbrych2026-10-27│Add list.discard() │─────── Type ───────│────────────────────────────────────────────────────────│ │Standards Track  588│850Wheel Variants:       Standards Track, Draft│Author │Informational    106│Providers             │Stan Ulbrych │Process           53▆│Michał Górny, Jonathan Dekhtiar, 2026-10-15│ ││Konstantin Schütze, Ralf Gommers│Discussions To │────── Status ──────│────────────────────────────────────────────────────────│https://discuss.python.org/t/pep-85 │Final            375│823None-aware access     Standards Track, Draft│ │Rejected         132│operators             │Status │Withdrawn         74│Marc Mueller2026-09-20│Draft │Draft             56│────────────────────────────────────────────────────────│ │Active            38│824None-coalescing       Standards Track, Draft│Type │Deferred          35│operators             │Standards Track │Superseded        25│Marc Mueller2026-09-20│ │Accepted          11│────────────────────────────────────────────────────────│Created │Provisional        1│849More Expressive Type  Standards Track, Draft│2026-10-27 (2 days ago) ││Expressions           │ │── Python Version ──│Imogen Hergeth2026-09-20│Python Version │None218│────────────────────────────────────────────────────────│3.16 │1.6                1│848Generational          Standards Track, Draft│ │2.0                9│Incremental Garbage   │Post History │2.1               25│Collection            │2025-10-12 (1 year, 1 month ago) 🔗 │2.2               24│Mark Shannon2026-09-16│2026-10-27 (2 days ago) 🔗 │2.3               26│────────────────────────────────────────────────────────│ │2.4               18│846Docstrings for Type   Standards Track, Draft│URL │2.5               24│Aliases               │https://peps.python.org/pep-0851/ │2.6               16│Bartosz Sławecki2026-09-06│ │2.7               12│────────────────────────────────────────────────────────│ │2.7.9              2│845Leading-Dot Value     Standards Track, Draft│ │2.7.12             1│Patterns              │ │2.8                1│Thomas Kehrenberg, Marc Mueller2026-08-25│ │2.x                1│────────────────────────────────────────────────────────│ │3.0               46│847Problem Details for   Standards Track, Draft│ │3.1                6│the Simple Repository │ │3.2               12│API                   │ │3.3               29│Luis Gonzalez, William Woodruff, Zsolt 2026-08-06│ │3.4               22│Dollenstein│ │3.4.3              1│────────────────────────────────────────────────────────│ │3.5               20│843Export Statement for  Standards Track, Draft│ │3.6               26│DRY Re-exports        │ │3.7               25│Neil Girdhar2026-08-05│ │3.8               20│────────────────────────────────────────────────────────│ │3.9               15│844``public`` and        Standards Track, Draft│ │3.10              21│``private`` builtins  │ │3.11              17│Barry Warsaw2026-08-05│ │3.12              25│────────────────────────────────────────────────────────│ │3.13              18│842Module Exports        Standards Track, Withdrawn│  f1 Help  f2 Notes  f3 Details  f4 View  f10 Quit  ^r Redownload ▏^p Commands

Peplum is a terminal-based lookup manager for Python Enhancement Proposals. It provides the ability to browse, filter and search the metadata for all the PEPs available via the PEP API.

Installation

pipx

The application can be installed using pipx:

pipx install peplum

uv

If you are a uv user you can:

uv tool install peplum

Also, if you do have uv installed, you can simply use uvx:

uvx peplum

to run peplum.

Homebrew

The package is available via Homebrew. Use the following commands to install:

brew tap davep/homebrew
brew install peplum

Running Peplum

Once you've installed Peplum using one of the above methods, you can run the application using the peplum command.

Command line options

Peplum has a number of command line options; they include:

-b, --bindings

Prints the application commands whose keyboard bindings can be modified, giving the defaults too.

peplum --bindings
ChangeTheme - Change the application's theme
    Default: f9
EditNotes - Edit the highlighted PEP's notes
    Default: f2
Escape - Back up through the panes, right to left, or exit the app if the navigation pane has focus
    Default: escape
FindPEP - Find and jump to a specific PEP
    Default: p
Help - Show help for and information about the application
    Default: f1, ?
Quit - Quit the application
    Default: f10, ctrl+q
RedownloadPEPs - Redownload the list of PEPs
    Default: ctrl+r
Search - Search for text anywhere in the PEPs
    Default: /
SearchAuthor - Search for an author then filter by them
    Default: u
SearchPythonVersion - Search for a Python version and then filter by it
    Default: v
SearchStatus - Search for a PEP status and then filter by it
    Default: s
SearchType - Search for a PEP type and then filter by it
    Default: t
ShowAll - Clear any filters and show all PEPs
    Default: a
SortByCreated - Sort PEPs by their created date
    Default: 2
SortByNumber - Sort PEPs by their number
    Default: 1
SortByTitle - Sort PEPs by their title
    Default: 3
ToggleAuthorsSortOrder - Toggle the sort order of the authors in the navigation panel
    Default: A
TogglePEPDetails - Toggle the display of the PEP details panel
    Default: f3
TogglePythonVersionsSortOrder - Toggle the sort order of Python versions in the navigation panel
    Default: V
ToggleSortOrder - Toggle the current sort order
    Default: minus
ToggleStatusesSortOrder - Toggle the sort order of the statuses in the navigation panel
    Default: S
ToggleTypesSortOrder - Toggle the sort order of types in the navigation panel
    Default: T
ViewPEP - View the source of the currently-highlighted PEP
    Default: f4

-h, --help

Prints the help for the peplum command.

peplum --help
usage: peplum [-h] [-v] [--license] [-b]
              [-s {number,created,title,~number,~created,~title}] [-t THEME]
              [pep]

The PEP lookup manager for your terminal.

positional arguments:
  pep                   A PEP to highlight

options:
  -h, --help            show this help message and exit
  -v, --version         Show version information
  --license, --licence  Show license information
  -b, --bindings        List commands that can have their bindings changed
  -s, --sort-by {number,created,title,~number,~created,~title}
                        Set the sort order for the PEPs; prefix with '~' for
                        reverse order
  -t, --theme THEME     Set the theme for the application (set to ? to list
                        available themes)

v1.1.0

--license, --licence

Prints a summary of Peplum's license.

peplum --license
Peplum - The PEP lookup manager for the terminal.  
Copyright (C) 2025 Dave Pearson

This program is free software: you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the Free
Software Foundation, either version 3 of the License, or (at your option)
any later version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see <https://www.gnu.org/licenses/>.

-t, --theme

Sets Peplum's theme; this overrides and changes any previous theme choice made via the user interface.

To see a list of available themes use ? as the theme name:

peplum --theme=?
atom-one-dark
atom-one-light
catppuccin-frappe
catppuccin-latte
catppuccin-macchiato
catppuccin-mocha
dracula
flexoki
gruvbox
monokai
nord
rose-pine
rose-pine-dawn
rose-pine-moon
solarized-dark
solarized-light
textual-dark
textual-light
tokyo-night

-v, --version

Prints the version number of Peplum.

peplum --version
peplum v1.1.0

Getting help

A great way to get to know Peplum is to read the help screen. Once in the application you can see this by pressing F1.

The Peplum Help Screen Peplum v1.1.0 — All; Sorted by Date Created (reversed) (747) │All [a]747│851Add list.discard()    Standards Track, Draft│Title │┌─ Help ─────────────────────────────────────────────────────────────────────────────────┐ │─────── Type││ │Standards Tra││ │Informational││ │Process      │Peplum v1.1.0│ │││ │────── Status││on.org/t/pep-85 │Final        ││ │Rejected     │Navigation Panel│ │Withdrawn    ││ │Draft        │Select items in this panel to filter the list of PEPs.│ │Active       ││ │Deferred     ││ │Superseded   │Main application keys and commands│ │Accepted     │▃│ │Provisional  │The following keys and commands can be used anywhere here on the main screen.│go) │││ │── Python Ver│┌────────────┬─────┬──────────────────────────────────────────────────────────────┐│ │None││Command│Key│Description││ │1.6          │├────────────┼─────┼──────────────────────────────────────────────────────────────┤│ │2.0          ││Change│f9│Change the application's theme││ │2.1          ││Theme││││1 month ago) 🔗 │2.2          │├────────────┼─────┼──────────────────────────────────────────────────────────────┤│go) 🔗 │2.3          ││Edit Notes│f2│Edit the highlighted PEP's notes││ │2.4          │├────────────┼─────┼──────────────────────────────────────────────────────────────┤│ │2.5          ││Escape│esc│Back up through the panes, right to left, or exit the app if││org/pep-0851/ │2.6          ││││the navigation pane has focus││ │2.7          │├────────────┼─────┼──────────────────────────────────────────────────────────────┤│ │2.7.9        ││Find PEP│p│Find and jump to a specific PEP││ │2.7.12       │├────────────┼─────┼──────────────────────────────────────────────────────────────┤│ │2.8          ││Help│f1,│Show help for and information about the application││ │2.x          │││?│││ │3.0          │├────────────┼─────┼──────────────────────────────────────────────────────────────┤│ │3.1          ││Quit│f10│Quit the application││ │3.2          │├────────────┼─────┼──────────────────────────────────────────────────────────────┤│ │3.3          ││Redownload│^r│Redownload the list of PEPs││ │3.4          ││All PEPs││││ │3.4.3        │├────────────┼─────┼──────────────────────────────────────────────────────────────┤│ │3.5          ││Search│/│Search for text anywhere in the PEPs││ │3.6          │├────────────┼─────┼──────────────────────────────────────────────────────────────┤│ │3.7          │────────────────────────────────────────────────────────────────────────────────────────│ │3.8          │▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔│ │3.9          │ Okay [Esc]│ │3.10         │▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁│ │3.11         └────────────────────────────────────────────────────────────────────────────────────────┘ │3.12              25│────────────────────────────────────────────────────────│ │3.13              18│842Module Exports        Standards Track, Withdrawn│  f1 Help  f2 Notes  f3 Details  f4 View  f10 Quit  ^r Redownload ▏^p Commands

The command palette

Another way of discovering commands and keys in Peplum is to use the command palette (by default you can call it with ctrl+p or meta+x).

The Peplum Command Palette Peplum v1.1.0 — All; Sorted by Date Created (reversed) (747) │All [a]747│851Add list.discard()    Standards Track, Draft│Title ││Stan Ulbrych2026-10-27│Add list.discard() │─────── Type▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔▔ │Standards Tra │InformationalSearch for commands… │Process       │ │────── StatusChange Theme [f9]on.org/t/pep-85 │Final        Change the application's theme │Rejected     Edit Notes [f2] │Withdrawn    Edit the highlighted PEP's notes │Draft        Escape [esc] │Active       Back up through the panes, right to left, or exit the app if the navigation pane has │Deferred     focus │Superseded   Find PEP [p] │Accepted     Find and jump to a specific PEP │Provisional  Help [f1]go) │Show help for and information about the application │── Python VerQuit [f10] │NoneQuit the application │1.6          Redownload All PEPs [^r] │2.0          Redownload the list of PEPs │2.1          Search [/]1 month ago) 🔗 │2.2          Search for text anywhere in the PEPsgo) 🔗 │2.3          Search Author [u] │2.4          Search for an author then filter by them │2.5          Search Python Version [v]org/pep-0851/ │2.6          Search for a Python version and then filter by it │2.7          Search Status [s] │2.7.9        Search for a PEP status and then filter by it │2.7.12       Search Type [t]▆ │2.8          Search for a PEP type and then filter by it │2.x          Show All [a] │3.0          Clear any filters and show all PEPs │3.1          Sort By Created [2] │3.2          Sort PEPs by their created date │3.3          Sort By Number [1] │3.4          Sort PEPs by their number │3.4.3        Sort By Title [3] │3.5          Sort PEPs by their title │3.6          ▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁▁ │3.7               25│Neil Girdhar2026-08-05│ │3.8               20│────────────────────────────────────────────────────────│ │3.9               15│844``public`` and        Standards Track, Draft│ │3.10              21│``private`` builtins  │ │3.11              17│Barry Warsaw2026-08-05│ │3.12              25│────────────────────────────────────────────────────────│ │3.13              18│842Module Exports        Standards Track, Withdrawn│  f1 Help  f2 Notes  f3 Details  f4 View  f10 Quit  ^r Redownload ▏^p Commands

Questions and feedback

If you have any questions about Peplum, or you have ideas for how it might be improved, do please feel free to visit the discussion area and ask your question or suggest an improvement.

When doing so, please do search past discussions and also issues current and previous to make sure I've not already dealt with this, or don't have your proposed change already flagged as something to do.